window.Gleam.initSearch([{"doc":"lustre_ssg","title":"lustre_ssg","content":"# lustre_ssg\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_ssg)](https://hex.pm/packages/lustre_ssg)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_ssg/)\n\nA simple static site generator for [Lustre](https://github.com/lustre-labs/lustre)\nprojects, written in pure Gleam. `lustre_ssg` will run on both Gleam&#39;s Erlang and\nJavaScript targets. If you&#39;re using the JavaScript target, `lustre_ssg` is tested\nto work on both Node.js and Deno!\n\n## What it is\n\n`lustre_ssg` is a low-config static site generator for simple things like a\npersonal blog or documentation site. Declare your routes, tell `lustre_ssg` how\nto render them, and it will spit out a bunch of HTML files for you.\n\n## What it is not\n\n`lustre_ssg` is not a batteries-included framework for generating static sites.\nThere is no CLI, no built-in server, no fancy data fetching, and no client-side\nhydration. If you need those things, you will have to build them yourself!\n\n## Usage\n\n1. Add `lustre_ssg` as a development dependency to your Gleam project:\n\n```sh\n$ gleam add lustre_ssg --dev\n```\n\n2. Create a `build.gleam` file in your project&#39;s `src` directory.\n\n3. Import `lustre/ssg` and configure your routes:\n\n```gleam\nimport gleam/list\nimport gleam/map\nimport gleam/io\n\n// Some data for your site\nimport app/data/posts\n\n// Some functions for rendering pages\nimport app/page/index\nimport app/page/blog\nimport app/page/post\n\n// Import the static site generator\nimport lustre/ssg\n\npub fn main() {\n  let posts = map.from_list({\n    use post &lt;- list.map(posts.all())\n    #(post.id, post)\n  })\n\n  let build = ssg.new(&quot;./priv&quot;)\n    |&gt; ssg.add_static_route(&quot;/&quot;, index.view())\n    |&gt; ssg.add_static_route(&quot;/blog&quot;, blog.view(posts.all()))\n    |&gt; ssg.add_dynamic_route(&quot;/blog&quot;, posts, post.view)\n    |&gt; ssg.build\n\n  case build {\n    Ok(_) -&gt; io.println(&quot;Build succeeded!&quot;)\n    Error(e) -&gt; {\n      io.debug(e)\n      io.println(&quot;Build failed!&quot;)\n    }\n  }\n}\n```\n\n4. Run the build script to generate your static site!\n\n```sh\n$ gleam run -m build\n```\n\n```sh\n$ tree priv\n\npriv\n├── blog\n│   ├── wibble.html\n│   ├── wobble.html\n│   └── ...\n├── blog.html\n└── index.html\n```\n","url":"index.html"},{"doc":"lustre/ssg","title":"BuildError","content":"pub type BuildError {\n  CannotCreateTempDirectory(reason: simplifile.FileError)\n  CannotWriteStaticAsset(\n    reason: simplifile.FileError,\n    path: String,\n  )\n  CannotGenerateRoute(reason: simplifile.FileError, path: String)\n  CannotWriteToOutputDir(reason: simplifile.FileError)\n  CannotCleanupTempDir(reason: simplifile.FileError)\n}\n This type represents possible errors that can occur when building the site.\n\nCannotCreateTempDirectory(reason: simplifile.FileError)\n An error that can occur when trying to create a temporary directory to\n work in: when generating a static site, lustre_ssg first writes all the\n files in a temporary directory. After the generation is over, all the\n contents of the temporary directory are copied over to the actual output\n directory.\n\n\nCannotWriteStaticAsset(\n  reason: simplifile.FileError,\n  path: String,\n)\n An error that can occur when trying to write a static asset to a given\n path.\n\n\nCannotGenerateRoute(reason: simplifile.FileError, path: String)\n An error that can occur when trying to generate a route at a given path.\n\n\nCannotWriteToOutputDir(reason: simplifile.FileError)\n An error that can occur when the building step is over and all generated\n documents are moved from the temporary directory to the actual output\n directory.\n\n\nCannotCleanupTempDir(reason: simplifile.FileError)\n An error that can occur when trying to delete the temporary directory.\n\n\nSynonyms:\nlustre/ssg.BuildError\nlustre/ssg BuildError","url":"lustre/ssg.html#BuildError"},{"doc":"lustre/ssg","title":"Config","content":"pub opaque type Config(\n  has_static_routes,\n  has_static_dir,\n  use_index_routes,\n)\n The `Config` type tells `lustre_ssg` how to generate your site. It includes\n things like the output directory and any routes you have configured.\n\n The type parameters are used to track different facts about the configuration\n and prevent silly things from happening like building a site with no guaranteed\n routes.\n\n If you&#39;re looking at the generated documentation on hex.pm, these type parameters\n might be unhelpfully labelled &quot;a&quot;, &quot;b&quot;, &quot;c&quot;, etc. Here&#39;s a look at what these\n type parameters are called in the source code:\n\n \n pub opaque type Config(\n   has_static_routes,\n   has_static_dir,\n   use_index_routes\n )\n \n\n - `has_static_routes` indicates whether or not the configuration has at least\n   one static route and so is guarnateed to generate at least one HTML file.\n   It will be either `HasStaticRoutes` or `NoStaticRoutes`.\n\n   You need to add at least one static route before you can build your site\n   using [`build`](#build). This is to prevent you from providing empty dynamic\n   routes and accidentally building nothing.\n\n - `has_static_dir` indicates whether or not the configuration has a static\n   assets directory to copy. It will be either `HasStaticDir` or `NoStaticDir`.\n\n   The [`build`](#build) function will run regardless, but you may choose to\n   wrap this function yourself to provider stricter compile-time guarantees\n   if you want to ensure that your static assets are always configured.\n\n - `use_index_routes` indicates whether or not the configuration will generate\n   HTML files that correspond directly to the route provided or if an index.html\n   file will be generated at the route provided. It will be either `UseDirectRoutes`\n   or `UseIndexRoutes`.\n\n   As with `has_static_dir`, the [`build`](#build) function will run regardless,\n   but you may use this parameter for stricter compile-time guarantees.\n\n\nSynonyms:\nlustre/ssg.Config\nlustre/ssg Config","url":"lustre/ssg.html#Config"},{"doc":"lustre/ssg","title":"HasStaticDir","content":"pub type HasStaticDir\n This type is used to tag the `Config` through the different builder functions.\n It indicates a configuration that has a static assets directory to copy.\n\n\nSynonyms:\nlustre/ssg.HasStaticDir\nlustre/ssg HasStaticDir","url":"lustre/ssg.html#HasStaticDir"},{"doc":"lustre/ssg","title":"HasStaticRoutes","content":"pub type HasStaticRoutes\n This type is used to tag the `Config` through the different builder functions.\n It indicates a configuration that will generate least one static route.\n\n\nSynonyms:\nlustre/ssg.HasStaticRoutes\nlustre/ssg HasStaticRoutes","url":"lustre/ssg.html#HasStaticRoutes"},{"doc":"lustre/ssg","title":"NoStaticDir","content":"pub type NoStaticDir\n This type is used to tag the `Config` through the different builder functions.\n It indicates a configuration that does not have a statica ssets directory to\n copy.\n\n\nSynonyms:\nlustre/ssg.NoStaticDir\nlustre/ssg NoStaticDir","url":"lustre/ssg.html#NoStaticDir"},{"doc":"lustre/ssg","title":"NoStaticRoutes","content":"pub type NoStaticRoutes\n This type is used to tag the `Config` through the different builder functions.\n It indicates a configuration that will not generate any static routes.\n\n Your configuration must have at least one static route before it can be passed\n to `build`. This is to prevent you from accidentally building a completely\n empty site.\n\n\nSynonyms:\nlustre/ssg.NoStaticRoutes\nlustre/ssg NoStaticRoutes","url":"lustre/ssg.html#NoStaticRoutes"},{"doc":"lustre/ssg","title":"UseDirectRoutes","content":"pub type UseDirectRoutes\n This type is used to tag the `Config` through the different builder functions.\n It indicates a configuration that will generate HTML files that correspond\n directly to the route provided, for example the route &quot;/blog&quot; will generate\n a file at &quot;/blog.html&quot;.\n\n\nSynonyms:\nlustre/ssg.UseDirectRoutes\nlustre/ssg UseDirectRoutes","url":"lustre/ssg.html#UseDirectRoutes"},{"doc":"lustre/ssg","title":"UseIndexRoutes","content":"pub type UseIndexRoutes\n This type is used to tag the `Config` through the different builder functions.\n It indicates a configuration that will generate an `index.html` file at the\n route provided, for example the route &quot;/blog&quot; will generate a file at\n &quot;/blog/index.html&quot;.\n\n\nSynonyms:\nlustre/ssg.UseIndexRoutes\nlustre/ssg UseIndexRoutes","url":"lustre/ssg.html#UseIndexRoutes"},{"doc":"lustre/ssg","title":"add_dynamic_route","content":"pub fn add_dynamic_route(\n  config: Config(a, b, c),\n  path: String,\n  data: Dict(String, d),\n  page: fn(d) -&gt; Element(e),\n) -&gt; Config(a, b, c)\n Configure a map of dynamic routes to be generated. As with `add_static_route`\n the base path should be the route that each page will be available at when\n served by a HTTP server.\n\n The initial path is the base for all dynamic routes to be generated. The\n keys of the `data` map will be used to generate the dynamic routes. For\n example, to generate dynamic routes for a blog where each page is a post\n with the route &quot;/blog/:post&quot; you might do:\n\n \n let posts = [\n   #(&quot;hello-world&quot;, Post(...)),\n   #(&quot;why-lustre-is-great&quot;, Post(...)),\n ]\n\n ...\n\n ssg.config(&quot;./dist&quot;)\n |&gt; ...\n |&gt; ssg.add_dynamic_route(&quot;/blog&quot;, posts, render_post)\n \n\n Paths are converted to kebab-case and lowercased. This means that the path\n &quot;/Blog&quot; will be available at &quot;/blog&quot; and and &quot;/About me&quot; will be available at\n &quot;/about-me&quot;.\n\nSynonyms:\nlustre/ssg.add_dynamic_route\nlustre/ssg add_dynamic_route","url":"lustre/ssg.html#add_dynamic_route"},{"doc":"lustre/ssg","title":"add_static_asset","content":"pub fn add_static_asset(\n  config: Config(a, b, c),\n  path: String,\n  content: String,\n) -&gt; Config(a, b, c)\n Include a static asset in the generated site. This might be something you\n want to be generated at build time, like a robots.txt, a sitemap.xml, or\n an RSS feed.\n\n The path should be the path that the asset will be available at when served\n by an HTTP server. For example, the path &quot;/robots.txt&quot; would be available at\n &quot;https://your_site.com/robots.txt&quot;. The path will be converted to kebab-case\n and lowercased.\n\n If you have configured a static assets directory to be copied over, any static\n asset added here will overwrite any file with the same path.\n\nSynonyms:\nlustre/ssg.add_static_asset\nlustre/ssg add_static_asset","url":"lustre/ssg.html#add_static_asset"},{"doc":"lustre/ssg","title":"add_static_dir","content":"pub fn add_static_dir(\n  config: Config(a, NoStaticDir, b),\n  path: String,\n) -&gt; Config(a, HasStaticDir, b)\n Include a static directory from which all files will be copied over into\n the temporary build directory before building the site.\n\nSynonyms:\nlustre/ssg.add_static_dir\nlustre/ssg add_static_dir","url":"lustre/ssg.html#add_static_dir"},{"doc":"lustre/ssg","title":"add_static_route","content":"pub fn add_static_route(\n  config: Config(a, b, c),\n  path: String,\n  page: Element(d),\n) -&gt; Config(HasStaticRoutes, b, c)\n Configure a static route to be generated. The path should be the route that\n the page will be available at when served by a HTTP server. For example the\n path &quot;/blog&quot; would be available at &quot;https://your_site.com/blog&quot;.\n\n You need to add at least one static route before you can build your site. This\n is to prevent you from providing empty dynamic routes and accidentally building\n nothing.\n\n Paths are converted to kebab-case and lowercased. This means that the path\n &quot;/Blog&quot; will be available at &quot;/blog&quot; and and &quot;/About me&quot; will be available at\n &quot;/about-me&quot;.\n\nSynonyms:\nlustre/ssg.add_static_route\nlustre/ssg add_static_route","url":"lustre/ssg.html#add_static_route"},{"doc":"lustre/ssg","title":"add_static_xml","content":"pub fn add_static_xml(\n  config: Config(a, b, c),\n  path: String,\n  page: Element(d),\n) -&gt; Config(a, b, c)\n\n\nSynonyms:\nlustre/ssg.add_static_xml\nlustre/ssg add_static_xml","url":"lustre/ssg.html#add_static_xml"},{"doc":"lustre/ssg","title":"build","content":"pub fn build(\n  config: Config(HasStaticRoutes, a, b),\n) -&gt; Result(Nil, BuildError)\n Generate the static site. This will delete the output directory if it already\n exists and then generate all of the routes configured. If a static assets\n directory has been configured, its contents will be recursively copied into\n the output directory **before** any routes are generated.\n\nSynonyms:\nlustre/ssg.build\nlustre/ssg build","url":"lustre/ssg.html#build"},{"doc":"lustre/ssg","title":"new","content":"pub fn new(\n  out_dir: String,\n) -&gt; Config(NoStaticRoutes, NoStaticDir, UseDirectRoutes)\n Initialise a new configuration for the static site generator. If you pass a\n relative path it will be resolved relative to the current working directory,\n _not_ the directory of the Gleam file.\n\nSynonyms:\nlustre/ssg.new\nlustre/ssg new","url":"lustre/ssg.html#new"},{"doc":"lustre/ssg","title":"use_index_routes","content":"pub fn use_index_routes(\n  config: Config(a, b, c),\n) -&gt; Config(a, b, UseIndexRoutes)\n Configure the static site generator to generate an `index.html` file at any\n static route provided. For example, the route &quot;/blog&quot; will generate a file\n at &quot;/blog/index.html&quot;.\n\nSynonyms:\nlustre/ssg.use_index_routes\nlustre/ssg use_index_routes","url":"lustre/ssg.html#use_index_routes"},{"doc":"lustre/ssg","title":"lustre/ssg","content":"","url":"lustre/ssg.html"},{"doc":"lustre/ssg/atom","title":"author","content":"pub fn author(\n  attrs: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.author\nlustre/ssg/atom author","url":"lustre/ssg/atom.html#author"},{"doc":"lustre/ssg/atom","title":"category","content":"pub fn category(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.category\nlustre/ssg/atom category","url":"lustre/ssg/atom.html#category"},{"doc":"lustre/ssg/atom","title":"content","content":"pub fn content(\n  attrs: List(Attribute(a)),\n  content: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.content\nlustre/ssg/atom content","url":"lustre/ssg/atom.html#content"},{"doc":"lustre/ssg/atom","title":"contributor","content":"pub fn contributor(\n  attrs: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.contributor\nlustre/ssg/atom contributor","url":"lustre/ssg/atom.html#contributor"},{"doc":"lustre/ssg/atom","title":"email","content":"pub fn email(\n  attrs: List(Attribute(a)),\n  email: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.email\nlustre/ssg/atom email","url":"lustre/ssg/atom.html#email"},{"doc":"lustre/ssg/atom","title":"entry","content":"pub fn entry(\n  attrs: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.entry\nlustre/ssg/atom entry","url":"lustre/ssg/atom.html#entry"},{"doc":"lustre/ssg/atom","title":"feed","content":"pub fn feed(\n  attrs: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.feed\nlustre/ssg/atom feed","url":"lustre/ssg/atom.html#feed"},{"doc":"lustre/ssg/atom","title":"generator","content":"pub fn generator(\n  attrs: List(Attribute(a)),\n  name: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.generator\nlustre/ssg/atom generator","url":"lustre/ssg/atom.html#generator"},{"doc":"lustre/ssg/atom","title":"icon","content":"pub fn icon(\n  attrs: List(Attribute(a)),\n  path: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.icon\nlustre/ssg/atom icon","url":"lustre/ssg/atom.html#icon"},{"doc":"lustre/ssg/atom","title":"id","content":"pub fn id(attrs: List(Attribute(a)), uri: String) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.id\nlustre/ssg/atom id","url":"lustre/ssg/atom.html#id"},{"doc":"lustre/ssg/atom","title":"link","content":"pub fn link(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.link\nlustre/ssg/atom link","url":"lustre/ssg/atom.html#link"},{"doc":"lustre/ssg/atom","title":"logo","content":"pub fn logo(\n  attrs: List(Attribute(a)),\n  path: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.logo\nlustre/ssg/atom logo","url":"lustre/ssg/atom.html#logo"},{"doc":"lustre/ssg/atom","title":"name","content":"pub fn name(\n  attrs: List(Attribute(a)),\n  name: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.name\nlustre/ssg/atom name","url":"lustre/ssg/atom.html#name"},{"doc":"lustre/ssg/atom","title":"published","content":"pub fn published(\n  attrs: List(Attribute(a)),\n  iso_timestamp: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.published\nlustre/ssg/atom published","url":"lustre/ssg/atom.html#published"},{"doc":"lustre/ssg/atom","title":"rights","content":"pub fn rights(\n  attrs: List(Attribute(a)),\n  rights: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.rights\nlustre/ssg/atom rights","url":"lustre/ssg/atom.html#rights"},{"doc":"lustre/ssg/atom","title":"source","content":"pub fn source(\n  attrs: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.source\nlustre/ssg/atom source","url":"lustre/ssg/atom.html#source"},{"doc":"lustre/ssg/atom","title":"subtitle","content":"pub fn subtitle(\n  attrs: List(Attribute(a)),\n  subtitle: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.subtitle\nlustre/ssg/atom subtitle","url":"lustre/ssg/atom.html#subtitle"},{"doc":"lustre/ssg/atom","title":"summary","content":"pub fn summary(\n  attrs: List(Attribute(a)),\n  summary: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.summary\nlustre/ssg/atom summary","url":"lustre/ssg/atom.html#summary"},{"doc":"lustre/ssg/atom","title":"title","content":"pub fn title(\n  attrs: List(Attribute(a)),\n  title: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.title\nlustre/ssg/atom title","url":"lustre/ssg/atom.html#title"},{"doc":"lustre/ssg/atom","title":"updated","content":"pub fn updated(\n  attrs: List(Attribute(a)),\n  iso_timestamp: String,\n) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.updated\nlustre/ssg/atom updated","url":"lustre/ssg/atom.html#updated"},{"doc":"lustre/ssg/atom","title":"uri","content":"pub fn uri(attrs: List(Attribute(a)), uri: String) -&gt; Element(a)\n\nSynonyms:\nlustre/ssg/atom.uri\nlustre/ssg/atom uri","url":"lustre/ssg/atom.html#uri"},{"doc":"lustre/ssg/atom","title":"lustre/ssg/atom","content":"","url":"lustre/ssg/atom.html"},{"doc":"lustre/ssg/djot","title":"Renderer","content":"pub type Renderer(view) {\n  Renderer(\n    codeblock: fn(Dict(String, String), Option(String), String) -&gt;\n      view,\n    emphasis: fn(List(view)) -&gt; view,\n    heading: fn(Dict(String, String), Int, List(view)) -&gt; view,\n    link: fn(jot.Destination, Dict(String, String), List(view)) -&gt;\n      view,\n    paragraph: fn(Dict(String, String), List(view)) -&gt; view,\n    strong: fn(List(view)) -&gt; view,\n    text: fn(String) -&gt; view,\n    code: fn(String) -&gt; view,\n    image: fn(jot.Destination, String) -&gt; view,\n    linebreak: fn() -&gt; view,\n  )\n}\n A renderer for a djot document knows how to turn each block or inline element\n into some custom view. That view could be anything, but it&#39;s typically a\n Lustre element.\n\n Some ideas for other renderers include:\n\n - A renderer that turns a djot document into a JSON object\n - A renderer that generates a table of contents\n - A renderer that generates Nakai elements instead of Lustre ones\n\n Sometimes a custom renderer might need access to the TOML metadata of a\n document. For that, take a look at the [`render_with_metadata`](#render_with_metadata)\n function.\n\n This renderer is compatible with **v1.0.1** of the [jot](https://hexdocs.pm/jot/jot.html)\n package.\n\nRenderer(\n  codeblock: fn(Dict(String, String), Option(String), String) -&gt;\n    view,\n  emphasis: fn(List(view)) -&gt; view,\n  heading: fn(Dict(String, String), Int, List(view)) -&gt; view,\n  link: fn(jot.Destination, Dict(String, String), List(view)) -&gt;\n    view,\n  paragraph: fn(Dict(String, String), List(view)) -&gt; view,\n  strong: fn(List(view)) -&gt; view,\n  text: fn(String) -&gt; view,\n  code: fn(String) -&gt; view,\n  image: fn(jot.Destination, String) -&gt; view,\n  linebreak: fn() -&gt; view,\n)\n\n\nSynonyms:\nlustre/ssg/djot.Renderer\nlustre/ssg/djot Renderer","url":"lustre/ssg/djot.html#Renderer"},{"doc":"lustre/ssg/djot","title":"content","content":"pub fn content(document: String) -&gt; String\n Extract the djot content from a document with optional frontmatter. If the\n document does not have frontmatter, this acts as an identity function.\n\nSynonyms:\nlustre/ssg/djot.content\nlustre/ssg/djot content","url":"lustre/ssg/djot.html#content"},{"doc":"lustre/ssg/djot","title":"default_renderer","content":"pub fn default_renderer() -&gt; Renderer(Element(a))\n The default renderer generates some sensible Lustre elements from a djot\n document. You can use this if you need a quick drop-in renderer for some\n markup in a Lustre project.\n\nSynonyms:\nlustre/ssg/djot.default_renderer\nlustre/ssg/djot default_renderer","url":"lustre/ssg/djot.html#default_renderer"},{"doc":"lustre/ssg/djot","title":"frontmatter","content":"pub fn frontmatter(document: String) -&gt; Result(String, Nil)\n Extract the frontmatter string from a djot document. Frontmatter is anything\n between two lines of three dashes, like this:\n\n djot\n ---\n title = &quot;My Document&quot;\n ---\n\n # My Document\n\n ...\n \n\n The document **must** start with exactly three dashes and a newline for there\n to be any frontmatter. If there is no frontmatter, this function returns\n `Error(Nil)`,\n\nSynonyms:\nlustre/ssg/djot.frontmatter\nlustre/ssg/djot frontmatter","url":"lustre/ssg/djot.html#frontmatter"},{"doc":"lustre/ssg/djot","title":"metadata","content":"pub fn metadata(\n  document: String,\n) -&gt; Result(Dict(String, Toml), ParseError)\n Extract the TOML metadata from a djot document. This takes the [`frontmatter`](#frontmatter)\n and parses it as TOML. If there is *no* frontmatter, this function returns\n an empty dictionary.\n\n If the frontmatter is invalid TOML, this function returns a TOML parse error.\n\nSynonyms:\nlustre/ssg/djot.metadata\nlustre/ssg/djot metadata","url":"lustre/ssg/djot.html#metadata"},{"doc":"lustre/ssg/djot","title":"render","content":"pub fn render(document: String, renderer: Renderer(a)) -&gt; List(a)\n Render a djot document using the given renderer. If the document contains\n [`frontmatter`](#frontmatter) it is stripped out before rendering.\n\nSynonyms:\nlustre/ssg/djot.render\nlustre/ssg/djot render","url":"lustre/ssg/djot.html#render"},{"doc":"lustre/ssg/djot","title":"render_with_metadata","content":"pub fn render_with_metadata(\n  document: String,\n  renderer: fn(Dict(String, Toml)) -&gt; Renderer(a),\n) -&gt; Result(List(a), ParseError)\n Render a djot document using the given renderer. TOML metadata is extracted\n from the document&#39;s frontmatter and passed to the renderer. If the frontmatter\n is invalid TOML this function will return the TOML parse error, but if there\n is no frontmatter to parse this function will succeed and just pass an empty\n dictionary to the renderer.\n\nSynonyms:\nlustre/ssg/djot.render_with_metadata\nlustre/ssg/djot render_with_metadata","url":"lustre/ssg/djot.html#render_with_metadata"},{"doc":"lustre/ssg/djot","title":"lustre/ssg/djot","content":"","url":"lustre/ssg/djot.html"}]);